#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 binary-instances
version:              1.0.4
visibility:           public
id:                   binary-instances-1.0.4-KlbUwj5u35OHNNqbYEJYwo
key:                  binary-instances-1.0.4-KlbUwj5u35OHNNqbYEJYwo
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/binary-instances#readme
synopsis:             Orphan instances for binary
description:
    `binary-instances` defines orphan instances for types in some popular packages.

category:             Web
abi:                  d1a8f4623686ca475acb69e9346c55f4
exposed:              True
exposed-modules:
    Data.Binary.Instances Data.Binary.Instances.Aeson
    Data.Binary.Instances.CaseInsensitive
    Data.Binary.Instances.Hashable Data.Binary.Instances.Primitive
    Data.Binary.Instances.Scientific Data.Binary.Instances.Tagged
    Data.Binary.Instances.Text Data.Binary.Instances.Time
    Data.Binary.Instances.UnorderedContainers
    Data.Binary.Instances.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/binary-instances-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-instances
hs-libraries:         HSbinary-instances-1.0.4-KlbUwj5u35OHNNqbYEJYwo
depends:
    aeson-2.2.1.0-B4RqQZAnAt5HkJbmyrGfNz base-4.18.2.1 binary-0.8.9.1
    binary-orphans-1.0.5-83h38JmUaGJEk4ZbboOyjx
    case-insensitive-1.2.1.0-IN9jUwBK0bV3S6k2Bgrxup
    hashable-1.4.7.0-DcMaISCS2qf3eQMEkeWh0S
    primitive-0.9.1.0-GLiCOtvZzNK1Mxdf6aZ1nZ
    scientific-0.3.8.0-HLdXvCiO3QbIUecoSvRoN5
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-binary-0.2.1.1-Gj3kZI8lApt9vSR18tt3q2
    time-compat-1.9.8-A8fNcCLQbec8wAc3j9Rzf7
    unordered-containers-0.2.20.1-C4c13QuwLgs7TJHWi6VHCN
    vector-0.13.2.0-AKpLem9JWa2IilUORfhwQi
    vector-binary-instances-0.2.5.2-EwnYwsJqvkA70L9uou7vlo

haddock-interfaces:
    /usr/share/doc/haskell-binary-instances/html/binary-instances.haddock

haddock-html:         /usr/share/doc/haskell-binary-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

